@@ -1,5 +1,5 @@
 package FormValidator::Tiny;
-$FormValidator::Tiny::VERSION = '0.002';
+$FormValidator::Tiny::VERSION = '0.003';
 use v5.18;
 use warnings;
 
@@ -17,6 +17,7 @@ BEGIN {
         length_in_range
         equal_to
         number_in_range
+        one_of
     );
     my @export_filters = qw(
         split_by
@@ -27,6 +28,7 @@ BEGIN {
         validation => \@EXPORT,
         predicates => \@export_predicates,
         filters    => \@export_filters,
+        all        => [ @EXPORT, @export_predicates, @export_filters ],
     );
 }
 
@@ -609,6 +611,23 @@ sub number_in_range {
     }
 }
 
+sub one_of {
+    die "at least one value must be provided to one_of"
+        unless @_ > 0;
+
+    my @enum = @_;
+    return sub {
+        my ($value) = @_;
+        for my $allowed (@enum) {
+            return (1, '') if $value eq $allowed;
+        }
+
+        return (0, 'Must be one of: '
+            . _comma_and( map { qq["$_"] } @enum )
+        );
+    };
+}
+
 sub split_by {
     my ($by, $count) = @_;
 
@@ -664,7 +683,7 @@ FormValidator::Tiny - A tiny form validator
 
 =head1 VERSION
 
-version 0.002
+version 0.003
 
 =head1 SYNOPSIS
 
@@ -751,7 +770,7 @@ version 0.002
 The API of this module is still under development and could change, but probably won't.
 
 There are lots for form validators, but this one aims to be the one that just
-one thing and does it well without involving anything else if it can. If you
+does one thing and does it well without involving anything else if it can. If you
 just need a small form validator without installing all of CPAN, this will do
 that. If you want to install all of CPAN and use a readable form validation spec
 syntax, I hope this will do that too.
@@ -782,6 +801,8 @@ This includes the built-in predicate helpers, used with C<must> and C<must>-like
 
 =item number_in_range
 
+=item one_of
+
 =back
 
 =item :filters
@@ -796,6 +817,10 @@ This includes the build-in filter helpers, used with C<into> and C<into>-like di
 
 =back
 
+=item :all
+
+All of the above.
+
 =back
 
 =head1 FUNCTIONS
@@ -852,7 +877,7 @@ section.
 
     my ($params, $errors) = validate_form $spec, $input_parameters;
 
-Compares the given parameters agains the named spec. The C<$input_parameters>
+Compares the given parameters against the named spec. The C<$input_parameters>
 may be provided as either a hash or an array of alternating key-value pairs. All
 keys and values must be provided as strings.
 
@@ -908,7 +933,17 @@ the value must be exactly equal to another field in the input.
     must => number_in_range(100, 500)
     must => number_in_range(exclusive => 100, exclusive => 500)
 
-Returns a predicate for must that requires the integer to be within the given range. The endpoints are inclusive by default. You can add the word "exclusive" before a value to make the comparison exclusive instead. Using a '*' indicates no limit at that end of the range.
+Returns a predicate for must that requires the integer to be within the given
+range. The endpoints are inclusive by default. You can add the word "exclusive"
+before a value to make the comparison exclusive instead. Using a '*' indicates
+no limit at that end of the range.
+
+=head2 one_of
+
+    must => one_of(qw( a b c )),
+
+Returns a predicate that requires the value to exactly match one of the
+enumerated values.
 
 =head2 split_by
 
@@ -955,7 +990,7 @@ changes the key used for input.
 
     multiple => 1
 
-The multiple input declaration tells the validator weather to interpret the
+The multiple input declaration tells the validator whether to interpret the
 input parameter as a multiple input or not. Without this declaration or with it
 set to 0, the validator will interpret multiple inputs as a single value,
 ignoring all but the last. With this declaration, it treat the input as multiple
@@ -1160,11 +1195,11 @@ declaration.
 
     ($valid, $message) = $code->($value, \%fields);
 
-The subroutine will be passed a two values. The first is the input to test
+The subroutine will be passed two values. The first is the input to test
 (which will also be set in the localalized copy of C<$_>). This second value
 passed is rest of the input as processing currently stands.
 
-The return value must be a two element list.
+The return value must be a two elements list.
 
 =over
 
